@@ -33,6 +33,7 @@ namespace Php
 TypeBuilder::TypeBuilder()
     : TypeBuilderBase()
     , m_gotTypeFromDocComment(false)
+    , m_gotTypeFromTypeHint(false)
     , m_gotReturnTypeFromDocComment(false)
 {
 }
@@ -402,6 +403,16 @@ void TypeBuilder::visitParameter(ParameterAst *node)
 
     AbstractType::Ptr type = parameterType(node, phpDocTypehint, editor(), currentContext());
 
+    if (node->defaultValue) {
+        QString symbol = m_editor->parseSession()->symbol(node->defaultValue);
+
+        if (node->parameterType && node->parameterType->typehint &&
+                symbol.compare(QLatin1String("null"), Qt::CaseInsensitive) != 0 &&
+                type->contains(new IntegralTypeExtended(IntegralTypeExtended::TypeObject))) {
+            reportError(i18n("Default value for parameters with an object type can only be NULL."), node->defaultValue);
+        }
+    }
+
     openAbstractType(type);
     TypeBuilderBase::visitParameter(node);
     closeType();
